==> startapp_sdk_flutter-0.0.6.tar.gz: ios/Classes/StartappPlugin.m <==
#import "StartappPlugin.h"


// VIEW
@interface StartappBanner : NSObject<FlutterPlatformView>
-(instancetype)initWithWithFrame:(CGRect)frame
                  viewIdentifier:(int64_t)viewId
                       arguments:(id)args
                 binaryMessenger:(NSObject<FlutterBinaryMessenger>*)messenger;
- (STABannerView*)view;
@end

@implementation StartappBanner {
  int64_t _viewId;
  FlutterMethodChannel* _channel;
  STABannerView* bannerView;
}

- (instancetype)initWithWithFrame:(CGRect)frame
                   viewIdentifier:(int64_t)viewId
                        arguments:(id)args
                  binaryMessenger:(NSObject<FlutterBinaryMessenger>*)messenger {
      _viewId = viewId;
      NSString* channelName = [NSString stringWithFormat:@"startapp/banner_%lld", viewId];
      bannerView = [[STABannerView alloc] initWithSize:STA_PortraitAdSize_320x50 autoOrigin:STAAdOrigin_Bottom
                                            withDelegate:self];
      [bannerView loadAd];
      _channel = [FlutterMethodChannel methodChannelWithName:channelName binaryMessenger:messenger];
  return self;
}

- (void) bannerAdIsReadyToDisplay:(STABannerView*)banner {
    bannerView = bannerView;
    NSLog(@"Event log: bannerAdIsReadyToDisplay" );
}

- (void) didDisplayBannerAd:(STABannerView*)banner {
    bannerView = bannerView;
    NSLog(@"Event log: didDisplayBannerAd" );
    [_channel invokeMethod:@"onReceiveAd" arguments:(nil) ];
}

- (void) failedLoadBannerAd:(STABannerView*)banner withError:(NSError *)error {
    bannerView = bannerView;
    NSLog(@"Event log: failedLoadBannerAd" );
    [_channel invokeMethod:@"onFailedToReceiveAd" arguments:(nil) ];
}
- (void) didClickBannerAd:(STABannerView*)banner {
    bannerView = bannerView;
    NSLog(@"Event log: didClickBannerAd" );
    [_channel invokeMethod:@"onClick" arguments:(nil) ];
}
- (void) didCloseBannerInAppStore:(STABannerView*)banner {
    bannerView = bannerView;
    NSLog(@"Event log: didCloseBannerInAppStore" );
    [_channel invokeMethod:@"onClose" arguments:(nil) ];
}

- (STABannerView*)view {
  return bannerView;
}

@end



// FACTORY
NS_ASSUME_NONNULL_BEGIN

@interface StartappBannerFactory : NSObject<FlutterPlatformViewFactory>
- (instancetype)initWithMessenger:(NSObject<FlutterBinaryMessenger>*)messager;
@end

NS_ASSUME_NONNULL_END

@implementation StartappBannerFactory

{
    NSObject<FlutterBinaryMessenger>*_messenger;
}

- (instancetype )initWithMessenger:(NSObject<FlutterBinaryMessenger> *)messager{
    self = [super init];
    if (self) {
        _messenger = messager;
    }
    return self;
}

-(NSObject<FlutterMessageCodec>*)createArgsCodec {
   return [FlutterStandardMessageCodec sharedInstance];
}

- (NSObject<FlutterPlatformView> *)createWithFrame:(CGRect)frame viewIdentifier:(int64_t)viewId arguments:(id)args {
    StartappBanner *webView = [[StartappBanner alloc] initWithWithFrame:frame viewIdentifier:viewId arguments:args binaryMessenger:_messenger];
    return webView;
}

@end



@implementation StartappPlugin

NSString *pluginKey = @"startapp/banner";

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"startapp"
            binaryMessenger:[registrar messenger]];
  StartappPlugin* instance = [[StartappPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
  [registrar registerViewFactory: [[StartappBannerFactory alloc] initWithMessenger:registrar.messenger] withId: pluginKey];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([@"initialize" isEqualToString:call.method]) {
        NSString *appId = call.arguments[@"appId"];
        STAStartAppSDK* sdk = [STAStartAppSDK sharedInstance];
        sdk.appID = appId;
        [sdk disableReturnAd];
        result([NSNumber numberWithBool:YES]);
    } else {
       result(FlutterMethodNotImplemented);
    }
}

@end

==> startapp_sdk_flutter-0.0.7.tar.gz: ios/Classes/StartappPlugin.m <==
#import "StartappPlugin.h"


// VIEW
@interface StartappBanner : NSObject<FlutterPlatformView>
-(instancetype)initWithWithFrame:(CGRect)frame
                  viewIdentifier:(int64_t)viewId
                       arguments:(id)args
                 binaryMessenger:(NSObject<FlutterBinaryMessenger>*)messenger;
- (STABannerView*)view;
@end

@implementation StartappBanner {
  int64_t _viewId;
  FlutterMethodChannel* _channel;
  STABannerView* bannerView;
}

- (instancetype)initWithWithFrame:(CGRect)frame
                   viewIdentifier:(int64_t)viewId
                        arguments:(id)args
                  binaryMessenger:(NSObject<FlutterBinaryMessenger>*)messenger {
      _viewId = viewId;
      NSString* channelName = [NSString stringWithFormat:@"startapp/banner_%lld", viewId];
    if (bannerView == nil) {
        bannerView = [[STABannerView alloc] initWithSize:STA_PortraitAdSize_320x50 autoOrigin:STAAdOrigin_Bottom
                                                  withDelegate:self];
    }
      _channel = [FlutterMethodChannel methodChannelWithName:channelName binaryMessenger:messenger];
  return self;
}

- (void) bannerAdIsReadyToDisplay:(STABannerView*)banner {
    bannerView = banner;
    [bannerView loadAd];
    NSLog(@"Event log: bannerAdIsReadyToDisplay" );
}

- (void) didDisplayBannerAd:(STABannerView*)banner {
    bannerView = banner;
    NSLog(@"Event log: didDisplayBannerAd" );
    [_channel invokeMethod:@"onReceiveAd" arguments:(nil) ];
}

- (void) failedLoadBannerAd:(STABannerView*)banner withError:(NSError *)error {
    bannerView = banner;
    [bannerView loadAd];
    NSLog(@"Event log: failedLoadBannerAd" );
    [_channel invokeMethod:@"onFailedToReceiveAd" arguments:(nil) ];
}
- (void) didClickBannerAd:(STABannerView*)banner {
    bannerView = banner;
    [bannerView loadAd];
    NSLog(@"Event log: didClickBannerAd" );
    [_channel invokeMethod:@"onClick" arguments:(nil) ];
}
- (void) didCloseBannerInAppStore:(STABannerView*)banner {
    NSLog(@"Event log: didCloseBannerInAppStore" );
    [_channel invokeMethod:@"onClose" arguments:(nil) ];
}

- (STABannerView*)view {
  return bannerView;
}

@end



// FACTORY
NS_ASSUME_NONNULL_BEGIN

@interface StartappBannerFactory : NSObject<FlutterPlatformViewFactory>
- (instancetype)initWithMessenger:(NSObject<FlutterBinaryMessenger>*)messager;
@end

NS_ASSUME_NONNULL_END

@implementation StartappBannerFactory

{
    NSObject<FlutterBinaryMessenger>*_messenger;
}

- (instancetype )initWithMessenger:(NSObject<FlutterBinaryMessenger> *)messager{
    self = [super init];
    if (self) {
        _messenger = messager;
    }
    return self;
}

-(NSObject<FlutterMessageCodec>*)createArgsCodec {
   return [FlutterStandardMessageCodec sharedInstance];
}

- (NSObject<FlutterPlatformView> *)createWithFrame:(CGRect)frame viewIdentifier:(int64_t)viewId arguments:(id)args {
    StartappBanner *webView = [[StartappBanner alloc] initWithWithFrame:frame viewIdentifier:viewId arguments:args binaryMessenger:_messenger];
    return webView;
}

@end



@implementation StartappPlugin

NSString *pluginKey = @"startapp/banner";

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"startapp"
            binaryMessenger:[registrar messenger]];
  StartappPlugin* instance = [[StartappPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
  [registrar registerViewFactory: [[StartappBannerFactory alloc] initWithMessenger:registrar.messenger] withId: pluginKey];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([@"initialize" isEqualToString:call.method]) {
        NSString *appId = call.arguments[@"appId"];
        STAStartAppSDK* sdk = [STAStartAppSDK sharedInstance];
        sdk.appID = appId;
        [sdk disableReturnAd];
        result([NSNumber numberWithBool:YES]);
    } else {
       result(FlutterMethodNotImplemented);
    }
}

@end
